@@ -1,12 +1,12 @@
 package File::Copy::Undoable;
 
-our $DATE = '2014-12-05'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Builtin::Logged qw(system);
 use File::MoreUtil qw(file_exists);
@@ -162,15 +162,31 @@ File::Copy::Undoable - Copy file/directory using rsync, with undo support
 
 =head1 VERSION
 
-This document describes version 0.06 of File::Copy::Undoable (from Perl distribution File-Copy-Undoable), released on 2014-12-05.
+This document describes version 0.07 of File::Copy::Undoable (from Perl distribution File-Copy-Undoable), released on 2015-08-17.
+
+=head1 FAQ
+
+=head2 Why do you use rsync? Why not, say, File::Copy::Recursive?
+
+With C<rsync>, we can continue interrupted transfer. We need this ability for
+recovery. Also, C<rsync> can handle hardlinks and preservation of ownership,
+something which L<File::Copy::Recursive> currently does not do. And, being
+implemented in C, it might be faster when processing large files/trees.
+
+=head1 SEE ALSO
+
+L<Setup>
+
+L<Rinci::Transaction>
 
 =head1 FUNCTIONS
 
 
 =head2 cp(%args) -> [status, msg, result, meta]
 
-Copy file/directory using rsync, with undo support.
+{en_US Copy file/directory using rsync, with undo support}.
 
+{en_US 
 On do, will copy C<source> to C<target> (which must not exist beforehand). On
 undo, will trash C<target>.
 
@@ -180,6 +196,7 @@ checked; only existence.
 Fixable state: C<source> exists and C<target> doesn't exist.
 
 Unfixable state: C<source> does not exist.
+}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -188,39 +205,47 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<rsync_opts> => I<array> (default: ["-a"])
+=item * B<rsync_opts> => I<array[str]> (default: ["-a"])
 
-Rsync options.
+{en_US Rsync options}.
 
+{en_US 
 By default, C<-a> is used. You can add, for example, C<--delete> or other rsync
 options.
+}
 
 =item * B<source>* => I<str>
 
 =item * B<target>* => I<str>
 
-Target location.
+{en_US Target location}.
 
+{en_US 
 Note that to avoid ambiguity, you must specify full location instead of just
 directory name. For example: cp(source=>'/dir', target=>'/a') will copy /dir to
 /a and cp(source=>'/dir', target=>'/a/dir') will copy /dir to /a/dir.
+}
 
 =item * B<target_group> => I<str>
 
-Set group of target.
+{en_US Set group of target}.
 
+{en_US 
 See C<target_owner>.
+}
 
 =item * B<target_owner> => I<str>
 
-Set ownership of target.
+{en_US Set ownership of target}.
 
+{en_US 
 If set, will do a C<chmod -Rh> on the target after rsync to set ownership. This
 usually requires super-user privileges. An example of this is copying files on
 behalf of user from a source that is inaccessible by the user (e.g. a system
 backup location). Or, setting up user's home directory when creating a user.
 
 Will do nothing if not running as super-user.
+}
 
 =back
 
@@ -250,8 +275,6 @@ For more information on transaction, see L<Rinci::Transaction>.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -261,22 +284,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
-
-=head1 FAQ
-
-=head2 Why do you use rsync? Why not, say, File::Copy::Recursive?
-
-With C<rsync>, we can continue interrupted transfer. We need this ability for
-recovery. Also, C<rsync> can handle hardlinks and preservation of ownership,
-something which L<File::Copy::Recursive> currently does not do. And, being
-implemented in C, it might be faster when processing large files/trees.
-
-=head1 SEE ALSO
-
-L<Setup>
-
-L<Rinci::Transaction>
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -284,7 +292,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/File-Copy-
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-File-Copy-Undoable>.
+Source repository is at L<https://github.com/sharyanto/perl-File-Copy-Undoable>.
 
 =head1 BUGS
 
@@ -300,7 +308,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
